@@ -20,11 +20,21 @@
 from pydolphinscheduler.tasks.condition import FAILURE, SUCCESS, And, Condition, Or
 from pydolphinscheduler.tasks.datax import CustomDataX, DataX
 from pydolphinscheduler.tasks.dependent import Dependent
+from pydolphinscheduler.tasks.dvc import DVCDownload, DVCInit, DVCUpload
 from pydolphinscheduler.tasks.flink import Flink
 from pydolphinscheduler.tasks.http import Http
 from pydolphinscheduler.tasks.map_reduce import MR
+from pydolphinscheduler.tasks.mlflow import (
+    MLflowModels,
+    MLFlowProjectsAutoML,
+    MLFlowProjectsBasicAlgorithm,
+    MLFlowProjectsCustom,
+)
+from pydolphinscheduler.tasks.openmldb import OpenMLDB
 from pydolphinscheduler.tasks.procedure import Procedure
 from pydolphinscheduler.tasks.python import Python
+from pydolphinscheduler.tasks.pytorch import Pytorch
+from pydolphinscheduler.tasks.sagemaker import SageMaker
 from pydolphinscheduler.tasks.shell import Shell
 from pydolphinscheduler.tasks.spark import Spark
 from pydolphinscheduler.tasks.sql import Sql
@@ -34,15 +44,26 @@ from pydolphinscheduler.tasks.switch import Branch, Default, Switch, SwitchCondi
 __all__ = [
     "Condition",
     "DataX",
+    "CustomDataX",
     "Dependent",
+    "DVCInit",
+    "DVCUpload",
+    "DVCDownload",
     "Flink",
     "Http",
     "MR",
+    "OpenMLDB",
+    "MLFlowProjectsBasicAlgorithm",
+    "MLFlowProjectsCustom",
+    "MLFlowProjectsAutoML",
+    "MLflowModels",
     "Procedure",
     "Python",
+    "Pytorch",
     "Shell",
     "Spark",
     "Sql",
     "SubProcess",
     "Switch",
+    "SageMaker",
 ]
